* Prevent "more" messages from appearing
set more off
* Control line length
set linesize 150

********************************************************************************
*******             BEGIN DATA MANIPULATION FOR CHAPTER 2 EXAMPLE        *******
*******               CHANGE "filesave" to your directory                *******
********************************************************************************

* Defining global variable for file location to be replaced in code below
global filesave "C:\Dropbox\14_SPLH861\861_Example2"

* Import chapter 2 data into temporary file
use "$filesave\STATA_Chapter2.dta", clear
* Center continuous predictors
gen age85 = age - 85
gen grip9 = grip - 9
* Creating contrasts for dementia groups
gen demNF=0 
gen demNC=0 
* Demgroup = none   
replace demNF=0 if (demgroup==1)
replace demNC=0 if (demgroup==1)
* Demgroup = future 
replace demNF=1 if (demgroup==2)
replace demNC=0 if (demgroup==2)
* Demgroup = current
replace demNF=0 if (demgroup==3)
replace demNC=1 if (demgroup==3)  
* Labeling new variables
label variable age85  "age85: Age in Years (0=85)"
label variable grip9  "grip9: Grip Strength in Pounds (0=9)"
label variable demNF  "demNF: Dementia Contrast for None=0 vs Future=1"
label variable demNC  "demNC: Dementia Contrast for None=0 vs Current=1"
    
********************************************************************************
*******                       BEGIN EXAMPLE 2 MODELS                     *******
********************************************************************************

* Save results to separate file
log using $filesave\STATA_Example2_Output.log, replace name(STATA_Example2)

display as result "Eq 2.8: Adding Dementia Group"
display as result "Using Manual Group Contrasts so Reference=None"
mixed cognition c.age85 c.grip9 c.sexmw c.demNF c.demNC, ///
                || caseid: , noconstant variance reml,
      estat ic, n(550),
      test (c.age85=0) (c.grip9=0) (c.sexmw=0) (c.demNF=0) (c.demNC=0) // Model R2 Chi2-Test
      test (c.demNF=0) (c.demNC=0) // Omnibus Chi2-Test for Dementia Group
      lincom _cons*1 + c.demNF*0 + c.demNC*0 // Intercept for None Group
      lincom _cons*1 + c.demNF*1 + c.demNC*0 // Intercept for Future Group
      lincom _cons*1 + c.demNF*0 + c.demNC*1 // Intercept for Current Group
      lincom c.demNF*1  + c.demNC*0  // None   vs Future  Group
      lincom c.demNF*0  + c.demNC*1  // None   vs Current Group
      lincom c.demNF*-1 + c.demNC*1  // Future vs Current Group
      
display as result "Eq 2.9: Adding Age by Grip Interaction"
display as result "Age 0=85 Grip 0=9"
mixed cognition c.c.age85 c.c.grip9 c.c.sexmw c.demNF c.demNC c.c.age85#c.c.grip9, ///
                || caseid: , noconstant variance reml,
      estat ic, n(550),
      estat vce,
      predict PredAgeGrip, xb,
      margins, at (c.c.age85=(-5(5)5) c.c.grip9=(-3(3)3)) vsquish,
      lincom c.age85*1 + c.age85#c.grip9*-3 // Age Slope at Grip Strength =  6
      lincom c.age85*1 + c.age85#c.grip9*0  // Age Slope at Grip Strength =  9
      lincom c.age85*1 + c.age85#c.grip9*3  // Age Slope at Grip Strength = 12
      lincom c.grip9*1 + c.age85#c.grip9*-5 // Grip Strength Slope at Age = 80
      lincom c.grip9*1 + c.age85#c.grip9*0  // Grip Strength Slope at Age = 85
      lincom c.grip9*1 + c.age85#c.grip9*5  // Grip Strength Slope at Age = 90
  
display as result "Eq 2.18: Adding Sex by Age by Grip Three-Way Interaction"
display as result "Age 0=85 Grip 0=9 Sex 0=Men Dementia 0=None"
mixed cognition c.age85 c.grip9 c.sexmw c.demNF c.demNC ///
                c.age85#c.grip9 c.sexmw#c.demNF c.sexmw#c.demNC ///
                c.age85#c.sexmw c.grip9#c.sexmw c.age85#c.grip9#c.sexmw, /// 
                || caseid: , noconstant variance reml,
      estat ic, n(550),
      margins, at (c.c.age85=(-5(5)5) c.c.grip9=(-3(3)3) c.c.sexmw=(0(1)1)) vsquish,
* Request simple effects of Age for grip=6,9,12 by sex=M,W
lincom c.age85*1 + c.age85#c.grip9*-3 + c.age85#c.sexmw*0 + c.age85#c.grip9#c.sexmw*0
lincom c.age85*1 + c.age85#c.grip9*0  + c.age85#c.sexmw*0 + c.age85#c.grip9#c.sexmw*0
lincom c.age85*1 + c.age85#c.grip9*3  + c.age85#c.sexmw*0 + c.age85#c.grip9#c.sexmw*0
lincom c.age85*1 + c.age85#c.grip9*-3 + c.age85#c.sexmw*1 + c.age85#c.grip9#c.sexmw*-3
lincom c.age85*1 + c.age85#c.grip9*0  + c.age85#c.sexmw*1 + c.age85#c.grip9#c.sexmw*0
lincom c.age85*1 + c.age85#c.grip9*3  + c.age85#c.sexmw*1 + c.age85#c.grip9#c.sexmw*3
* Request simple effects of Grip for age=80,85,80 by sex=M,W
lincom c.grip9*1 + c.age85#c.grip9*-5 + c.grip9#c.sexmw*0 + c.age85#c.grip9#c.sexmw*0
lincom c.grip9*1 + c.age85#c.grip9*0  + c.grip9#c.sexmw*0 + c.age85#c.grip9#c.sexmw*0
lincom c.grip9*1 + c.age85#c.grip9*5  + c.grip9#c.sexmw*0 + c.age85#c.grip9#c.sexmw*0
lincom c.grip9*1 + c.age85#c.grip9*-5 + c.grip9#c.sexmw*1 + c.age85#c.grip9#c.sexmw*-5
lincom c.grip9*1 + c.age85#c.grip9*0  + c.grip9#c.sexmw*1 + c.age85#c.grip9#c.sexmw*0
lincom c.grip9*1 + c.age85#c.grip9*5  + c.grip9#c.sexmw*1 + c.age85#c.grip9#c.sexmw*5
* Request simple effects of Sex (hold demgroup 0=None) for age=80,85,90 by grip=6,9,12 
lincom c.sexmw*1 + c.age85#c.sexmw*-5 + c.grip9#c.sexmw*-3 + c.age85#c.grip9#c.sexmw*15
lincom c.sexmw*1 + c.age85#c.sexmw*0  + c.grip9#c.sexmw*-3 + c.age85#c.grip9#c.sexmw*0
lincom c.sexmw*1 + c.age85#c.sexmw*5  + c.grip9#c.sexmw*-3 + c.age85#c.grip9#c.sexmw*-15
lincom c.sexmw*1 + c.age85#c.sexmw*-5 + c.grip9#c.sexmw*0  + c.age85#c.grip9#c.sexmw*0
lincom c.sexmw*1 + c.age85#c.sexmw*0  + c.grip9#c.sexmw*0  + c.age85#c.grip9#c.sexmw*0
lincom c.sexmw*1 + c.age85#c.sexmw*5  + c.grip9#c.sexmw*0  + c.age85#c.grip9#c.sexmw*0
lincom c.sexmw*1 + c.age85#c.sexmw*-5 + c.grip9#c.sexmw*3  + c.age85#c.grip9#c.sexmw*-15
lincom c.sexmw*1 + c.age85#c.sexmw*0  + c.grip9#c.sexmw*3  + c.age85#c.grip9#c.sexmw*0
lincom c.sexmw*1 + c.age85#c.sexmw*5  + c.grip9#c.sexmw*3  + c.age85#c.grip9#c.sexmw*15
* Request simple two-way interactions of age*grip for M,W
lincom c.age85#c.grip9*1 + c.age85#c.grip9#c.sexmw*0
lincom c.age85#c.grip9*1 + c.age85#c.grip9#c.sexmw*1
* Request simple two-way interactions of age*sex for grip=6,9,12
lincom c.age85#c.sexmw*1 + c.age85#c.grip9#c.sexmw*-3
lincom c.age85#c.sexmw*1 + c.age85#c.grip9#c.sexmw*0
lincom c.age85#c.sexmw*1 + c.age85#c.grip9#c.sexmw*3
* Request simple two-way interactions of grip*sex for age=80,85,90
lincom c.grip9#c.sexmw*1 + c.age85#c.grip9#c.sexmw*-5
lincom c.grip9#c.sexmw*1 + c.age85#c.grip9#c.sexmw*0
lincom c.grip9#c.sexmw*1 + c.age85#c.grip9#c.sexmw*5      
	  
* Close log
log close STATA_Example2
